#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : chat
# @Time         : 2025/8/19 13:22
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : qwen-image


from openai import AsyncOpenAI, OpenAI, AsyncStream

from meutils.pipe import *
from meutils.decorators.retry import retrying
# from meutils.oss.ali_oss import qwenai_upload
from meutils.io.files_utils import to_bytes, guess_mime_type
from meutils.caches import rcache

from meutils.llm.openai_utils import to_openai_params, create_chat_completion_chunk, token_encoder

from meutils.config_utils.lark_utils import get_next_token_for_polling
from meutils.schemas.openai_types import chat_completion, chat_completion_chunk, CompletionRequest, CompletionUsage, \
    ChatCompletion

FEISHU_URL = "https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=PP1PGr"

base_url = "https://chat.qwen.ai/api/v2"
DEFAUL_MODEL = "qwen3-235b-a22b"
from fake_useragent import UserAgent

ua = UserAgent()

thinking_budget_mapping = {
    "low": 1000,
    "medium": 8000,
    "high": 24000
}

COOKIE = """
cna=KP9DIEqqyjUCATrw/+LjJV8F; _bl_uid=LXmp28z7dwezpmyejeXL9wh6U1Rb; cnaui=310cbdaf-3754-461c-a3ff-9ec8005329c9; aui=310cbdaf-3754-461c-a3ff-9ec8005329c9; sca=43897cb0; _gcl_au=1.1.106229673.1748312382.56762171.1748482542.1748482541; xlly_s=1; x-ap=ap-southeast-1; acw_tc=0a03e53917509898782217414e520e5edfcdef667dcbd83b767c0ce464fad4; token=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJpZCI6IjMxMGNiZGFmLTM3NTQtNDYxYy1hM2ZmLTllYzgwMDUzMjljOSIsImxhc3RfcGFzc3dvcmRfY2hhbmdlIjoxNzUwNjYwODczLCJleHAiOjE3NTM1ODE4ODV9.Npy24ubI717JmdSWMrodWSvVRHENgbJ7Knd-Yf158YE; atpsida=705b922fe336ee0d63fcc329_1750989888_2; SERVERID=e8c2af088c314df080fffe7d0976a96b|1750989892|1750910540; tfstk=gGtsWsqG4IKUeosYhNDUAMIBJRIbcvoz6-6vEKEaHGIOG-O2eZBabAYXRIR16hSOMpQpNtDMbtpTlWd2wNEAWA4XAOWy0FJtS6Ef3IDMbiQvps65XZYNg15fcKASLbor4dvGmGlra0WjM37NqSBAMS5d9TSfBJ35KivGmihEsEHyxdAMR0lwBiHCvt6uMiBYDMHC3TXOD1QY9yBR9iIAktIdpOX0DlCYWv9dtOsAMIQtdMChHfD7Ftg1sdMwtHJ00Jm2p6ZYDH6Ki1p6F9XBAwQOwwCQD9-CCN1JBhJB9QBXy3_MwXzN6UTkNTRZvlOWBCTRyhFKOivePI6WXYU5GCvpbwKt3zXhmFLRXnG76ppJBeLJBXzCdepwAw--No_MJCYllnlEqG8yUnbJXcNlTaXXNGLI9lOR4urPNGl0lJ_uc91rdva0oJN5AmdFjVAhW9X18vMQ6EbOK96ndva0oNBhCOMId5Lc.; isg=BNfX7gH7c3OJX_gfCBykQ2rtZk0hHKt-YCofVCkEq6YJWPSaPe8Dz9o-uvjGsIP2; ssxmod_itna=iqGxRDuQqWqxgDUxeKYI5q=xBDeMDWK07DzxC5750CDmxjKidKDUGQq7qdOamuu9XYkRGGm01DBL4qbDnqD80DQeDvYxk0K4MUPhDwpaW8YRw3Mz7GGb48aIzZGzY=0DgSdfOLpmxbD884rDYoDCqDSDxD99OdD4+3Dt4DIDAYDDxDWCeDBBWriDGpdhmbQVqmqvi2dxi3i3mPiDit8xi5bZendVL4zvDDlKPGf3WPt5xGnD0jmxhpdx038aoODzLiDbxEY698DtkHqPOK=MlTiRUXxAkDb9RG=Y2U3iA4G3DhkCXU3QBhxCqM2eeQmkeNzCwkjw/006DDAY2DlqTWweL04MKBeHhY5om5NUwYHuFiieQ0=/R=9iO9xTBhND4KF4dvyqz0/toqlqlzGDD; ssxmod_itna2=iqGxRDuQqWqxgDUxeKYI5q=xBDeMDWK07DzxC5750CDmxjKidKDUGQq7qdOamuu9XYkRGGmibDG85+YNY=exGa3Y64u5DBwiW7r++DxFqCdl=l77NQwckyAaCG64hkCOjO1pkcMRBdqj70N7nk=e94KEQYUxlf+2Dw=ViA+XKDde0uGS+eXgFkQqzYWe0Dd4oGbUj8L4QY4og345X2DjKDNOfQRgfeIKVRFQjqR098dBUrQsXBNQZcG1oBFAp4xkLYHl+W3OQW9ybPF4sML3t1tPX2T4DmCqKL+jN1XX94xpyA6k9+sgyBFY4zXOq7dHOuO3Gd3lidwdrk=8dNrOdrYQo33fobVS=MRF7nNQBC5d3kBbYdwtoxNBKmBiXoTfOTzOp3MT=ODXhxfO16Tta4vSW=ubtkEGgeQ/gKOwsVjmKDEY0NZ+ee7xlitvWmBbtk7ma7x1PinxtbitdadtYQOqG5AFEZbFxiSE6rDky7jiatQ0Fe7z6uDmYx4z5MGxMA5iDY7DtSLfNUYxU44D
""".strip()


class Completions(object):
    def __init__(self, api_key: Optional[str] = None):
        self.api_key = api_key

    async def create(self, request: CompletionRequest, api_key: Optional[str] = None, cookie: Optional[str] = None):
        api_key = api_key or await get_next_token_for_polling(FEISHU_URL)

        self.client = AsyncOpenAI(
            base_url=base_url,
            api_key=api_key,
            default_headers={
                'User-Agent': ua.random,
                'Cookie': cookie or COOKIE
            }
        )

        chat_id = await self.create_new_chat()


        payload = {
            "chat_id": chat_id,
            "incremental_output": True,
            "chat_mode": "normal",
            "model": "qwen3-235b-a22b",
            "messages": [
                {
                    "role": "user",
                    "content": "这只熊拿着五彩画板和画笔，站在画板前画画。",

                    "user_action": "recommendation",
                    "files": [
                        {
                            "type": "image",
                            "name": "example.png",
                            "file_type": "image",
                            "showType": "image",
                            "file_class": "vision",
                            "url": "https://img.alicdn.com/imgextra/i2/O1CN0137EBmZ276dnmyY0kx_!!6000000007748-2-tps-1024-1024.png"
                        }
                    ],
                    "models": [
                        "qwen3-235b-a22b"
                    ],
                    # "chat_type": "t2t",
                    "chat_type": "image_edit",

                    "feature_config": {
                        "thinking_enabled": request.enable_thinking or False,
                        "output_schema": "phase"
                    },
                    "extra": {
                        "meta": {
                            "subChatType": "t2t"
                        }
                    }
                }
            ]
        }

        payload = {**request.model_dump(), **payload}

        data = to_openai_params(payload)
        response = await self.client.chat.completions.create(**data, extra_query={"chat_id": chat_id})
        # response = self.do_response(response)

        if isinstance(response, AsyncStream):
            async for i in response:
                print(i)

        else:
            prompt_tokens = len(token_encoder.encode(str(request.messages)))
            completion_tokens = len(token_encoder.encode(str(response.choices[0].message.content)))
            usage = {
                "prompt_tokens": prompt_tokens,
                "completion_tokens": completion_tokens,
                "total_tokens": prompt_tokens + completion_tokens
            }
            response.usage = usage
            print(response)

        # return response

    async def create_new_chat(self):

        payload = {
            "title": "新建对话",
            "models": [DEFAUL_MODEL],
            "chat_mode": "normal",
            "chat_type": "t2i",
            "timestamp": time.time() * 1000 // 1
        }
        resp = await self.client.post('/chats/new', body=payload, cast_to=object)
        logger.debug(resp)
        return resp['data']['id']


if __name__ == '__main__':
    token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJpZCI6IjMxMGNiZGFmLTM3NTQtNDYxYy1hM2ZmLTllYzgwMDUzMjljOSIsImxhc3RfcGFzc3dvcmRfY2hhbmdlIjoxNzUwNjYwODczLCJleHAiOjE3NTgxNTc1Njh9.eihH3NVrzJCg9bdWb9mim9rGKTLKn1a66kW2Cqc0uPM"
    request = CompletionRequest(
        model="qwen3-235b-a22b",
        messages=[

            {
                "role": "user",
                # "content": [{"type": "text", "text": "周杰伦"}],
                "content": "这只熊拿着五彩画板和画笔，站在画板前画画。",

            }
        ],
        stream=True,

        enable_thinking=True

    )

    arun(Completions().create(request, token))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : generations
# @Time         : 2025/6/11 17:06
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 统一收口

from meutils.pipe import *
from meutils.llm.clients import AsyncClient
from meutils.llm.openai_utils import to_openai_params

from meutils.schemas.image_types import ImageRequest

from meutils.apis.fal.images import generate as fal_generate

from meutils.apis.gitee.image_to_3d import generate as image_to_3d_generate
from meutils.apis.gitee.openai_images import generate as gitee_images_generate


async def generate(
        request: ImageRequest,
        api_key: Optional[str] = None,
        base_url: Optional[str] = None,
):
    if base_url:  # 优先级最高
        client = AsyncClient(api_key=api_key, base_url=base_url)
        return await client.images.generate(**to_openai_params(request))

    if request.model.startswith("fal-ai"):
        return await fal_generate(request, api_key)

    if request.model in {"Hunyuan3D-2", "Hi3DGen", "Step1X-3D"}:
        return await image_to_3d_generate(request, api_key)

    if request.model in {"Qwen-Image", "FLUX_1-Krea-dev"}:
        return await gitee_images_generate(request, api_key)


# "flux.1-krea-dev"

if __name__ == '__main__':
    # arun(generate(ImageRequest(model="flux", prompt="笑起来")))
    arun(generate(ImageRequest(model="FLUX_1-Krea-dev", prompt="笑起来")))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : baidu_api
# @Time         : 2023/8/25 11:15
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *


class Location(BaseModel):
    top: int
    left: int
    width: int
    height: int


class OCRElement(BaseModel):
    words: str
    location: Location


class OCResult(BaseModel):
    element: List[OCRElement]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : demo
# @Time         : 2021/2/23 9:01 下午
# @Author       : yuanjie
# @WeChat       : 313303303
# @Software     : PyCharm
# @Description  : https://www.cnblogs.com/dachenzi/p/8242713.html

from jinja2 import Template, Environment, PackageLoader, FileSystemLoader

# env = Environment(loader=FileSystemLoader('./'))
env = Environment(loader=PackageLoader('meutils'))

template = env.get_template('demo.j2')


class A:
    safe = 1

    def __init__(self, username):
        self.username = username


content = template.render(
    name='liuhao', age='18', country='China',
    A=A,
    users=['u1', 'u2', 'u3'],
    my_dict={'k': 'v'},
)

print(content)

with open('./demo.conf', 'w') as fp:
    fp.write(content)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : avmerge
# @Time         : 2023/11/20 17:00
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://blog.51cto.com/u_16175450/6695076

from meutils.pipe import *
from moviepy.editor import VideoFileClip, AudioFileClip, concatenate_videoclips, CompositeVideoClip

audio_path = "/Users/betterme/Downloads/videoplayback.m4a"
audio_path = "audio.mp3"
video_path = "/Users/betterme/Downloads/videoplayback.mp4"

# 打开视频和音频
video_clip = VideoFileClip(video_path)
audio_clip = AudioFileClip(audio_path)

# final_clip = concatenate_videoclips([video_clip1, video_clip2])

# 将视频剪辑与音频剪辑连接起来
video_clip.set_audio(audio_clip)


# 导出带有音频的最终视频
video_clip.write_videofile("avmerged3.mp4")


#
# FileNotFoundError: [Errno 2] No such file or directory:\
#     'ffmpeg -hide_banner -y -i "/Users/betterme/PycharmProjects/AI/MeUtils/meutils/ai_video/output.mp4" ' \
#     '-ac 1 "/Users/betterme/PycharmProjects/AI/pyvideotrans/tmp/output/output.wav"'


def extract_audio(video__path, audio_path):
    my_clip = AudioFileClip(video__path)
    my_clip.write_audiofile(audio_path)
    return my_clip


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : deeplx
# @Time         : 2024/3/1 16:54
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from meutils.pipe import *
from meutils.schemas.translator_types import DeeplxRequest
from meutils.decorators.retry import retrying

from meutils.str_utils.regular_expression import has_chinese

from meutils.apis import niutrans
from meutils.llm.clients import zhipuai_client


@alru_cache
async def llm_translate(prompt):
    if not has_chinese(prompt):
        # logger.debug("直接返回")
        return prompt

    response = await zhipuai_client.chat.completions.create(
        model="glm-4-flash",
        messages=[
            {"role": "system", "content": "将所有输入的文本翻译成英文。请不用解释，直接翻译。"},
            {"role": "user", "content": f"文本：{prompt}"}
        ],
        temperature=0,
    )

    return response.choices[0].message.content


@alru_cache()
@retrying()
async def translate(
        request: DeeplxRequest,
        api_key: Optional[str] = None,
):
    """
    https://fakeopen.org/DeepLX/#%E6%8E%A5%E5%8F%A3%E5%9C%B0%E5%9D%80
    https://linux.do/t/topic/111737
    """
    if not request.text.strip(): return {}

    api_key = api_key or "pOnI-G2dDExp_DdXlDhPH2gbIx1DTBEo3JHZ3dam3bw"  # todo

    url = f"https://api.deeplx.org/{api_key}/translate"

    payload = request.model_dump()
    try:
        async with httpx.AsyncClient(timeout=15) as client:
            response = await client.post(url, json=payload)
            data = response.json()
            # logger.debug(data)
            if not data.get('data'):
                logger.error(data)
                raise Exception('DeeplxRequest error')
            else:
                return data
    except Exception as e:
        logger.error(e)
        _ = await niutrans.translate(request.text, 'auto', request.target_lang.lower())
        return {'data': _}


if __name__ == '__main__':
    request = DeeplxRequest(text='讲个故事', source_lang='ZH', target_lang='EN')
    # with timer():
    #     arun(translate(request))

    # arun(translate_prompt('把小鸭子放在女人的T恤上面。'))

    # arun(llm_translate("这是一个文本"))
    arun(llm_translate("你说yes"))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : oneapi_types
# @Time         : 2024/6/28 10:13
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from meutils.pipe import *
from meutils.data.oneapi import NOTICE, FOOTER

BASE_URL = "https://api.chatfire.cn"


class ModelGroupInfo(BaseModel):
    """注：信息JSON共有以下键值，均全为string类型：name（厂商名称）、desc（厂商介绍，支持MD）、icon（厂商图标链接，不定义则会自动匹配默认图标库）、notice（厂商使用公告说明，支持MD）"""
    name: str

    desc: Optional[str] = None

    icon: Optional[str] = None

    notice: Optional[str] = None


class ModelInfo(BaseModel):
    """note（模型说明，支持MD）、icon（模型图标链接，不定义则会自动匹配默认图标库）、tags（模型标签，多个｜分割）、group（模型归属分组，例如OpenAI，或与下方【模型厂商信息中的Key相对应】）"""
    note: Optional[str] = None

    icon: Optional[str] = None

    tags: Optional[str] = None

    """ModelGroupInfo.name"""
    group: Optional[str] = None


class ChannelInfo(BaseModel):
    id: Optional[Union[int, str]] = None  # 不存在就新建
    type: int = 1  # 枚举值 openai

    name: str = ''
    tag: str = ''
    group: str = 'default'

    base_url: str = ''
    key: str  # 与id相对应
    models: str = 'MODEL'

    access_token: str = ''
    openai_organization: str = ''
    test_model: str = ''
    status: int = 1
    weight: int = 0
    created_time: int = Field(default_factory=lambda: int(time.time()))
    test_time: int = 0
    response_time: int = 0
    other: str = ''

    balance: int = 0
    balance_updated_time: int = 0

    used_quota: float = 0.001
    upstream_user_quota: int = 0

    model_mapping: Union[str, dict] = ""  # json

    headers: str = ''  # json
    status_code_mapping: Union[str, dict] = ''
    priority: int = 0
    auto_ban: int = 1
    empty_response_retry: int = 0
    not_use_key: int = 0
    remark: str = ''
    mj_relax_limit: int = 99
    mj_fast_limit: int = 99
    mj_turbo_limit: int = 99
    other_info: str = ''
    channel_ratio: int = 1
    error_return_429: int = 0
    setting: Union[str, dict] = ''
    # "setting": "{\"force_format\":true,\"thinking_to_content\":false,\"proxy\":\"\",\"pass_through_body_enabled\":true,\"system_prompt\":\"\"}",

    """参数覆盖"""
    param_override: Union[str, dict] = ''  # json
    is_tools: bool = False

    # new
    max_input_tokens: int = 0
    multi_key_mode: str = "random"

    def __init__(self, /, **data: Any):
        super().__init__(**data)

        self.id = self.id or None

        self.name = f"""{str(datetime.datetime.now())[:10]} {self.name or self.base_url or "NAME"}"""
        self.tag = f"""{str(datetime.datetime.now())[:10]} {self.tag or self.base_url or "TAG"}"""
        self.group = self.group or self.base_url or "GROUP"

        self.setting = self.setting or ""
        self.param_override = self.param_override or ""
        self.model_mapping = self.model_mapping or ""
        self.status_code_mapping = self.status_code_mapping or ""
        if isinstance(self.model_mapping, dict):
            self.model_mapping = json.dumps(self.model_mapping)

        if isinstance(self.status_code_mapping, dict):
            self.status_code_mapping = json.dumps(self.status_code_mapping)

        if isinstance(self.param_override, dict):
            self.param_override = json.dumps(self.param_override)

        if isinstance(self.setting, dict):
            self.setting = json.dumps(self.setting)

        if self.used_quota < 10000:
            self.used_quota = int(self.used_quota * 500000)


# https://oss.ffire.cc/images/qw.jpeg?x-oss-process=image/format,jpg/resize,w_512
if __name__ == '__main__':
    # print(','.join(REDIRECT_MODEL.keys()))

    from meutils.apis.oneapi import option, channel

    # option()
    #
    # arun(channel.edit_channel(MODEL_PRICE))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : search_music
# @Time         : 2024/5/10 08:36
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://www.yyssq.cn/

from meutils.pipe import *


def search_music(
        query,
        filter_value="name",
        type_value: str = "netease",
        page_value: int = 1
):
    url = "https://www.yyssq.cn/"
    data = {
        "input": query,
        "filter": filter_value,
        "type": type_value,
        "page": page_value
    }
    headers = {
        "Content-Type": "application/x-www-form-urlencoded; charset=UTF-8",
        "X-Requested-With": "XMLHttpRequest"
    }
    response = httpx.post(url, data=data, headers=headers)
    if response.status_code != 200: response.raise_for_status()

    return response.json()


if __name__ == '__main__':
    # 搜索
    pprint(search_music("夏天")["data"][:2])



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : openai_asr
# @Time         : 2023/11/23 13:10
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description
import io
import os

import requests
from meutils.io.files_utils import to_file

from meutils.pipe import *
from openai import OpenAI

# response_format: Literal["json", "text", "srt", "verbose_json", "vtt"]
file = open(
    "f275d9ac-5a62-4bbe-baf9-3fa10e0332f4.mp3",
    'rb')  # 正确
# file=open("2022112519张健涛29.mp3", 'rb')
# file = httpx.get("https://oss.chatfire.cn/data/demo.mp3").content

client = OpenAI(
    # base_url="https://openai.chatfire.cn/v1",
    api_key=os.getenv("OPENAI_API_KEY") ,
    # api_key=os.getenv("OPENAI_API_KEY_OPENAI") + "-336",

    # api_key=os.getenv("SILICONFLOW_API_KEY"),
    # base_url=os.getenv("SILICONFLOW_BASE_URL")

    # base_url="http://0.0.0.0:8000/v1",
    # base_url="https://api.chatfire.cc/v2",
    # base_url="https://api.chatfire.cc/v1",

    # api_key=os.getenv("DEEPINFRA_API_KEY"),
    # base_url="https://api.deepinfra.com/v1/openai",
)
# client = OpenAI(
#     api_key=os.environ.get("GROQ_API_KEY"),
#     # base_url=os.getenv("GROQ_BASE_URL"),
#     base_url="https://groq.chatfire.cc/v1",
#
# )
with timer():
    file = Path('audio.mp3').read_bytes()
    file = Path("/Users/betterme/PycharmProjects/AI/MeUtils/meutils/ai_audio/x1.mp3").read_bytes()

    # file = Path('m4a.mp3')

    # file = Path("/Users/betterme/PycharmProjects/AI/MeUtils/meutils/ai_audio/example.mp3").read_bytes()

    # file = Path("/Users/betterme/PycharmProjects/AI/MeUtils/meutils/ai_audio/国外健身和生活设备市场观察及分析.mp3").read_bytes()

    # file = Path('audio.mp3').read_bytes()

    # file = arun(to_file(file))  # mp3后缀
    file = ('_.mp3', file)  # ok

    _ = client.audio.transcriptions.create(
        file=file,

        model="whisper-1",
        # model="openai/whisper-large",
        #
        # model="SenseVoiceSmall",
        # model="FunAudioLLM/SenseVoiceSmall",

        # model="distil-whisper/distil-large-v3-ct2",

        # model="asr",

        # model="sensevoice",
        # model="whisper-large-v3",
        # response_format="text",  # ["json", "text", "srt", "verbose_json", "vtt"]
        response_format="srt",  # ["json", "text", "srt", "verbose_json", "vtt"]
        # response_format="verbose_json",  # ["json", "text", "srt", "verbose_json", "vtt"]
        # response_format="vtt",  # ["json", "text", "srt", "verbose_json", "vtt"]

    )
    print(_)
    #
    # _ = client.audio.translations.create(
    #     file=file,
    #     # model="whisper-1",
    #     model="whisper-large-v3",
    #     # response_format="text",  # ["json", "text", "srt", "verbose_json", "vtt"]
    #     # response_format="srt",  # ["json", "text", "srt", "verbose_json", "vtt"]
    #     # response_format="verbose_json",  # ["json", "text", "srt", "verbose_json", "vtt"]
    #     # response_format="vtt",  # ["json", "text", "srt", "verbose_json", "vtt"]
    #
    # )
    # print(_)

# Transcription(text='健身需要注意适度和平衡 过度的锻炼可能会导致身体受伤 因此 进行健身活动前 最好先咨询医生 或专业的健身教练 制定一个适合自己的健身计划 一般来说 一周内进行150分钟的适度强度的有氧运动 或者75分钟的高强度有氧运动 加上每周两天的肌肉锻炼就能达到保持健康的目标')




# -*- coding: utf-8 -*-

from __future__ import absolute_import

from .match import match
from .types import TYPES, Type

# Expose supported matchers types
types = TYPES


def guess(obj):
    """
    Infers the type of the given input.

    Function is overloaded to accept multiple types in input
    and peform the needed type inference based on it.

    Args:
        obj: path to file, bytes or bytearray.

    Returns:
        The matched type instance. Otherwise None.

    Raises:
        TypeError: if obj is not a supported type.
    """
    return match(obj) if obj else None


def guess_mime(obj):
    """
    Infers the file type of the given input
    and returns its MIME type.

    Args:
        obj: path to file, bytes or bytearray.

    Returns:
        The matched MIME type as string. Otherwise None.

    Raises:
        TypeError: if obj is not a supported type.
    """
    kind = guess(obj)
    return kind.mime if kind else kind


def guess_extension(obj):
    """
    Infers the file type of the given input
    and returns its RFC file extension.

    Args:
        obj: path to file, bytes or bytearray.

    Returns:
        The matched file extension as string. Otherwise None.

    Raises:
        TypeError: if obj is not a supported type.
    """
    kind = guess(obj)
    return kind.extension if kind else kind


def get_type(mime=None, ext=None):
    """
    Returns the file type instance searching by
    MIME type or file extension.

    Args:
        ext: file extension string. E.g: jpg, png, mp4, mp3
        mime: MIME string. E.g: image/jpeg, video/mpeg

    Returns:
        The matched file type instance. Otherwise None.
    """
    for kind in types:
        if kind.extension == ext or kind.mime == mime:
            return kind
    return None


def add_type(instance):
    """
    Adds a new type matcher instance to the supported types.

    Args:
        instance: Type inherited instance.

    Returns:
        None
    """
    if not isinstance(instance, Type):
        raise TypeError('instance must inherit from filetype.types.Type')

    types.insert(0, instance)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : openai_images
# @Time         : 2024/10/16 08:54
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from openai import AsyncOpenAI

from meutils.pipe import *
from meutils.config_utils.lark_utils import get_next_token_for_polling
from meutils.llm.openai_utils import to_openai_images_params  # todo
from meutils.llm.check_utils import check_token_for_siliconflow
from meutils.notice.feishu import send_message as _send_message, AUDIO
from meutils.decorators.retry import retrying
from meutils.io.files_utils import to_bytes

from meutils.schemas.openai_types import STTRequest

FEISHU_URL = "https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=3aA5dH"
FEISHU_URL_FREE = "https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=xlvlrH"

BASE_URL = os.getenv("SILICONFLOW_BASE_URL")

DEFAULT_MODEL = "FunAudioLLM/SenseVoiceSmall"
MODELS = {
    "sensevoice": "FunAudioLLM/SenseVoiceSmall",
}

send_message = partial(
    _send_message,
    title=__name__,
    url=AUDIO
)

check_token = check_token_for_siliconflow
check_valid_token = partial(check_token_for_siliconflow, threshold=-1)


@retrying(max_retries=3, title=__name__)
async def asr(request: STTRequest, api_key: Optional[str] = None):
    api_key = api_key or await get_next_token_for_polling(FEISHU_URL_FREE, check_valid_token, from_redis=True)

    request.model = MODELS.get(request.model, DEFAULT_MODEL)
    request.file = ('_.mp3', await to_bytes(request.file))

    data = request.model_dump(exclude_none=True)

    client = AsyncOpenAI(base_url=BASE_URL, api_key=api_key)
    response = await client.audio.transcriptions.create(**data)
    return response


if __name__ == '__main__':
    request = STTRequest(
        model="sensevoice",
        file=Path("/Users/betterme/PycharmProjects/AI/MeUtils/meutils/ai_audio/asr/audio.mp3").read_bytes()
    )

    arun(asr(request))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : search
# @Time         : 2025/4/2 11:19
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *
from google import genai
from google.genai.types import Tool, GenerateContentConfig, GoogleSearch, HttpOptions, ToolCodeExecution, Retrieval

client = genai.Client(
    api_key="AIzaSyD19pv1qsYjx4ZKbfH6qvNdYzHMV2TxmPU",
    http_options=HttpOptions(
        base_url="https://all.chatfire.cc/genai"
    )
)

google_search_tool = Tool(
    google_search=GoogleSearch(),
)

# google_search_tool = {'function_declarations': None, 'retrieval': None, 'google_search': {}, 'google_search_retrieval': None, 'code_execution': None}
print(google_search_tool.model_dump())
model_id = "gemini-2.0-flash"

response = client.models.generate_content(
    model=model_id,
    contents="亚洲多国回应“特朗普关税暂停”",
    config=GenerateContentConfig(
        tools=[google_search_tool],
        system_instruction="用中文回答",
        # response_modalities=["TEXT"],
    )
)

for each in response.candidates[0].content.parts:
    print(each.text)
# Example response:
# The next total solar eclipse visible in the contiguous United States will be on ...

# To get grounding metadata as web content.
print(response.candidates[0].grounding_metadata.search_entry_point.rendered_content)
print(response.candidates[0].grounding_metadata.grounding_chunks)
# response.candidates[0].grounding_metadata.grounding_chunks[0].web



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : kaiyuan
# @Time         : 2024/12/18 16:03
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

import hmac
import zlib
import hashlib

from meutils.pipe import *
from meutils.caches.redis_cache import cache
from meutils.io.files_utils import to_bytes
from meutils.apis.jimeng.common import get_upload_token, get_headers, BASE_URL, FEISHU_URL, check_token
from meutils.notice.feishu import send_message_for_images
from meutils.config_utils.lark_utils import get_next_token_for_polling


def random_str(n):
    return ''.join(random.sample('zyxwvutsrqponmlkjihgfedcba0123456789', n))


def hash256(msg):
    return hashlib.sha256(msg.encode('utf-8')).hexdigest()


def hmac_hash256(key, msg):
    if type(key) == str:
        return hmac.new(key.encode('utf-8'), msg.encode('utf-8'), hashlib.sha256)
    elif type(key) == hmac.HMAC:
        return hmac.new(key.digest(), msg.encode('utf-8'), hashlib.sha256)


def fileCRC32(file_buffer):
    return hex(zlib.crc32(file_buffer) & 0xFFFFFFFF)[2:]


def u(params):
    new_params = sorted(params.items(), key=lambda x: x[0])
    new_params = [f"{k}={v}" for k, v in new_params]
    return "&".join(new_params)


class JJRequest:
    def __init__(self, e, t, api, method="GET", params=None, data=None, serviceName="imagex"):
        self.t = t
        self.e = e
        self.api = api
        self.method = method
        self.params = params
        self.data = data

        self.serviceName = serviceName

    def getAuthorization(self):
        return f"AWS4-HMAC-SHA256 Credential={self.e['access_key_id']}/{self.t[:8]}/cn-north-1/{self.serviceName}/aws4_request, SignedHeaders=x-amz-date;x-amz-security-token, Signature={self.signature()}"

    def signature(self):
        r = self.getSigningKey()
        return hmac_hash256(r, self.stringToSign()).hexdigest()

    def getSigningKey(self, r="cn-north-1"):
        n = self.serviceName

        o = hmac_hash256("AWS4" + self.e['secret_access_key'], str(self.t[0:8]))
        i = hmac_hash256(o, str(r))
        s = hmac_hash256(i, str(n))
        return hmac_hash256(s, "aws4_request")

    def stringToSign(self):
        t = []
        t.append("AWS4-HMAC-SHA256")
        t.append(self.t)
        t.append(self.credentialString())
        t.append(hash256(self.canonicalString()))
        return "\n".join(t)

    def credentialString(self, region="cn-north-1"):
        return "/".join([self.t[0:8], region, self.serviceName, "aws4_request"])

    def canonicalString(self):
        e = []
        e.append(self.method)
        e.append("/")
        e.append(u(self.params))
        e.append(self.canonicalHeaders())
        e.append(self.signedHeaders())
        e.append(self.hexEncodedBodyHash())
        return "\n".join(e)

    def canonicalHeaders(self):
        return f"x-amz-date:{self.t}\nx-amz-security-token:{self.e['session_token']}\n"

    def signedHeaders(self):
        return "x-amz-date;x-amz-security-token"

    def hexEncodedBodyHash(self):
        return hash256("")


# @cache(ttl=15 * 60)
async def upload(image: bytes, upload_token: dict):  # oss 跨账号不知道是否可以使用
    # e = auth = upload_token['data']['auth'] # 豆包
    data = upload_token['data']
    # service_id = data.get('service_id', '3jr8j4ixpe')  # 即梦 3jr8j4ixpe 豆包 a9rns2rl98

    service_id = data.get('space_name') or "3jr8j4ixpe"  # 即梦视频 tb4s082cfz

    if 'auth' in data:
        data = data['auth']

    session_token = data['session_token']

    t = time.strftime("%Y%m%dT%H%M%SZ", time.gmtime())

    # "ServiceId": "tb4s082cfz",
    params = {
        "Action": "ApplyImageUpload",
        "Version": "2018-08-01",
        "ServiceId": service_id,
        "s": random_str(10),

        # "FileExtension": ".png",  #####
        "FileSize": len(image),
    }

    r = JJRequest(data, t, "https://imagex.bytedanceapi.com/", method="GET", params=params)
    headers = {
        'authorization': r.getAuthorization(),
        'x-amz-date': t,
        'x-amz-security-token': session_token,
    }
    # logger.debug(headers)
    response = requests.get(r.api, params=params, headers=headers)
    response.raise_for_status()
    logger.debug(response.status_code)
    response = response.json()

    logger.debug(bjson(response))
    if "Result" not in response:
        return

    store_info = response['Result']['UploadAddress']['StoreInfos'][0]
    logger.debug(bjson(store_info))

    oss_uri = store_info['StoreUri']
    oss_token = store_info['Auth']

    headers = {
        "authorization": oss_token,
        "content-length": str(len(image)),
        "content-Type": "image/jpeg",
        "content-crc32": fileCRC32(image),
    }

    # oss_url = f"https://{resp['Result']['UploadAddress']['UploadHosts'][0]}/{oss_uri}"

    # image_resp = requests.put(  # post
    #     oss_url,
    #     headers=headers,
    #     data=image,
    # )
    # logger.debug(image_resp.json())

    # return get_url(StoreUri)

    # upload_url = f"https://tos-hl-x.snssdk.com/upload/v1/{oss_uri}"
    upload_url = f"https://{response['Result']['UploadAddress']['UploadHosts'][0]}/upload/v1/{oss_uri}"

    # response = requests.post(upload_url, headers=headers, data=image)
    # response.raise_for_status()
    # response = response.json()
    # logger.debug(response)

    async with httpx.AsyncClient(headers=headers, timeout=60) as client:
        response = await client.post(upload_url, content=image)
        response.raise_for_status()
        data = response.json()
        logger.debug(bjson(data))

    return oss_uri


async def upload_for_vod(image: bytes, upload_token: dict):  # oss 跨账号不知道是否可以使用
    """
                    "UploadHost": "tos-lf-x.snssdk.com",
                    "UploadHost": "tos-hl-x.snssdk.com",

    :param image:
    :param upload_token:
    :return:
    """
    # e = auth = upload_token['data']['auth'] # 豆包
    data = upload_token['data']
    service_id = data.get('space_name', 'tb4s082cfz')  # 即梦 3jr8j4ixpe 豆包 a9rns2rl98

    if 'auth' in data:
        data = data['auth']

    session_token = data['session_token']

    t = time.strftime("%Y%m%dT%H%M%SZ", time.gmtime())

    params = {
        "Action": "ApplyUploadInner",
        "Version": "2020-11-19",

        "ServiceId": service_id,
        # "SpaceName": "artist_op",
        # "SpaceName": "dreamina",

        "IsInner": "1",

        "FileType": "video",
        "FileSize": len(image),

        "s": random_str(10),

    }

    r = JJRequest(data, t, "https://vod.bytedanceapi.com/", method="GET", params=params, serviceName="vod")
    headers = {
        'authorization': r.getAuthorization(),
        'x-amz-date': t,
        'x-amz-security-token': session_token,
    }
    # logger.debug(headers)
    # response = requests.get(r.api, params=params, headers=headers)
    # response.raise_for_status()
    # logger.debug(response.status_code)
    # response = response.json()
    # logger.debug(bjson(response))

    async with httpx.AsyncClient(headers=headers, params=params, timeout=120) as client:
        response = await client.get(r.api)
        response.raise_for_status()
        response = response.json()
        logger.debug(bjson(response))

    if "Result" not in response:
        return

    upload_node = response['Result']['InnerUploadAddress']['UploadNodes'][0]
    store_info = upload_node['StoreInfos'][0]
    logger.debug(bjson(store_info))

    vid = upload_node['Vid']
    upload_host = upload_node['UploadHost']

    oss_uri = store_info['StoreUri']
    oss_token = store_info['Auth']

    headers = {
        "authorization": oss_token,
        "content-length": str(len(image)),
        "content-Type": "application/octet-stream",
        "content-crc32": fileCRC32(image),
    }

    # upload_url = f"https://tos-hl-x.snssdk.com/upload/v1/{oss_uri}"
    upload_url = f"https://{upload_host}/upload/v1/{oss_uri}"

    # response = requests.post(upload_url, headers=headers, data=image)
    # response.raise_for_status()
    # response = response.json()
    # logger.debug(response)

    async with httpx.AsyncClient(headers=headers, timeout=120) as client:
        response = await client.post(upload_url, content=image)
        response.raise_for_status()
        data = response.json()
        logger.debug(bjson(data))

    return vid, oss_uri


async def upload_for_image(image, token, biz: Optional[str] = None):  # todo: 跨账号token
    """image url base64 bytes"""
    if not image: return

    upload_token = await get_upload_token(token, biz)
    image_uri = await upload(await to_bytes(image), upload_token)
    return image_uri


async def upload_for_video(video, token):  # 跨账号token
    """video url base64 bytes
    """
    if not video: return

    upload_token = await get_upload_token(token)
    vid, uri = await upload_for_vod(await to_bytes(video), upload_token)
    return vid, uri


async def face_recognize(image, token: Optional[str] = None):
    """
    图片识别
    """
    # token = "1c21a9fe6a4230609d7ff13e5cec41ec"  # 跨账号测试

    token = token or await get_next_token_for_polling(FEISHU_URL, check_token)

    url = "/mweb/v1/face_recognize"
    headers = get_headers(url, token)

    image_uri = await upload_for_image(image, token)
    payload = {
        "image_uri_list": [
            image_uri
        ]
    }

    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=120) as client:
        response = await client.post(url, json=payload)
        response.raise_for_status()
        data = response.json()

        try:
            data['data']['image_uri'] = image_uri
            data['data']['face_recognize_list'][0][0]['type'] = ""
            data['data']['face_recognize_list'][0][0]['id'] = str(uuid.uuid4())
            data['data']['face_recognize_list'][0][0]['is_selected'] = True
        except Exception as e:
            logger.error(e)
            send_message_for_images(f"图片识别失败 {bjson(data)}", __name__)

        return data


if __name__ == "__main__":
    # 豆包
    token = "de2215a7bb8e442774cf388f03fac84c"

    # jimeng
    token = "ffeee346fbd19eceebb79a7bfbca4bfe"
    token = "34438eb03d165737122180caf62a8058"
    #
    # upload_token = arun(get_upload_token(token))

    #
    # with open("test.jpg", "rb") as f:
    #     file = image = f.read()
    #
    #     print(upload(image, upload_token))
    # print(upload_for_vod(image, upload_token))
    #
    # with timer():
    #     arun(upload_for_video("https://fal.media/files/koala/8teUPbRRMtAUTORDvqy0l.mp4", token))

    # with timer():
    #     arun(upload_for_image("https://oss.ffire.cc/files/kling_watermark.png", token))

    # with timer():
    #     url = "https://oss.ffire.cc/files/lipsync.mp3"
    #     # arun(upload_for_video("https://oss.ffire.cc/files/lipsync.mp3", token))
    #     arun(upload_for_video(url, token))
    image_url = "https://oss.ffire.cc/files/kling_watermark.png"
    # arun(face_recognize(image_url, token))
    # arun(face_recognize(image_url))

    token = "ed16bb360a4744696f88a7b52b7c10a3"

    arun(upload_for_image(image_url, token, "video"))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : luma_types
# @Time         : 2024/7/22 10:44
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

# {
#     "user_prompt": "Grazing cows move slowly across an idyllic meadow, the camera tracking alongside them in a smooth side-angle motion",
#     "expand_prompt": true,
#     "aspect_ratio": "16:9"
# }
BASE_URL = "https://internal-api.virginia.labs.lumalabs.ai/api/photon/v1"  # luma.chatfire.cc
BASE_URL = "https://luma.chatfire.cc/api/photon/v1"

EXAMPLES = [
    {
        "user_prompt": "清凉夏季美少女，微卷短发，运动服，林间石板路，斑驳光影，超级真实，16K",
        "expand_prompt": True,
        "aspect_ratio": "16:9"
    },

    {
        "user_prompt": "清凉夏季美少女，微卷短发，运动服，林间石板路，斑驳光影，超级真实，16K",
        "expand_prompt": True,
        "aspect_ratio": "16:9",
        "image_url": "https://h2.inkwai.com/bs2/upload-ylab-stunt/ai_portal/1721561429/3z7bHmSC1Y/3yrmpqh7typspfcchmepar.png",
        "image_end_url": "https://p2.a.kwimgs.com/bs2/upload-ylab-stunt/ai_portal/1721561524/GPoJWxBS8s/y9wlbuku3exeo7ra85s4su.png"
    },

]


# /user/generations/?offset=0&limit=12

# https://internal-api.virginia.labs.lumalabs.ai/api/photon/v1/generations/56d3e505-a1f5-475c-9ba7-8beeac8aa2ac/extend
class LumaRequest(BaseModel):
    user_prompt: str = ""
    expand_prompt: bool = True  # 提示词优化
    aspect_ratio: str = "16:9"
    image_url: str = ""
    image_end_url: str = ""

    # def __init__(self, /, **data: Any):
    #     super().__init__(**data)

    class Config:
        json_schema_extra = {
            "example": EXAMPLES
        }


if __name__ == '__main__':
    print(LumaRequest(user_prompt='xxxx'))
